"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CompressType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _CompressTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CompressType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Unzip: _CompressType.ValueType  # 0
    """unzip"""

    Original: _CompressType.ValueType  # 1
    """不操作"""

class CompressType(_CompressType, metaclass=_CompressTypeEnumTypeWrapper):
    """"""
    pass

Unzip: CompressType.ValueType  # 0
"""unzip"""

Original: CompressType.ValueType  # 1
"""不操作"""

global___CompressType = CompressType


class _EnvType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _EnvTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EnvType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Unknown: _EnvType.ValueType  # 0
    """"""

    Release: _EnvType.ValueType  # 1
    """"""

    Test: _EnvType.ValueType  # 2
    """"""

class EnvType(_EnvType, metaclass=_EnvTypeEnumTypeWrapper):
    """"""
    pass

Unknown: EnvType.ValueType  # 0
""""""

Release: EnvType.ValueType  # 1
""""""

Test: EnvType.ValueType  # 2
""""""

global___EnvType = EnvType


class _IncrementType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _IncrementTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IncrementType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Total: _IncrementType.ValueType  # 0
    """全量包"""

    Incremental: _IncrementType.ValueType  # 1
    """增量包"""

class IncrementType(_IncrementType, metaclass=_IncrementTypeEnumTypeWrapper):
    """"""
    pass

Total: IncrementType.ValueType  # 0
"""全量包"""

Incremental: IncrementType.ValueType  # 1
"""增量包"""

global___IncrementType = IncrementType


class _LevelType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _LevelTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LevelType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Undefined: _LevelType.ValueType  # 0
    """"""

    High: _LevelType.ValueType  # 1
    """高 需立即下载"""

    Middle: _LevelType.ValueType  # 2
    """中 可以延迟下载"""

    Low: _LevelType.ValueType  # 3
    """低 仅在业务方使用到时由业务方手动进行下载"""

class LevelType(_LevelType, metaclass=_LevelTypeEnumTypeWrapper):
    """"""
    pass

Undefined: LevelType.ValueType  # 0
""""""

High: LevelType.ValueType  # 1
"""高 需立即下载"""

Middle: LevelType.ValueType  # 2
"""中 可以延迟下载"""

Low: LevelType.ValueType  # 3
"""低 仅在业务方使用到时由业务方手动进行下载"""

global___LevelType = LevelType


class ListReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ENV_FIELD_NUMBER: builtins.int
    POOLS_FIELD_NUMBER: builtins.int
    LIST_VERSION_FIELD_NUMBER: builtins.int
    env: typing.Text
    """"""

    @property
    def pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PoolReply]:
        """"""
        pass
    list_version: builtins.int
    """"""

    def __init__(self,
        *,
        env: typing.Text = ...,
        pools: typing.Optional[typing.Iterable[global___PoolReply]] = ...,
        list_version: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["env",b"env","list_version",b"list_version","pools",b"pools"]) -> None: ...
global___ListReply = ListReply

class ListReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POOL_NAME_FIELD_NUMBER: builtins.int
    MODULE_NAME_FIELD_NUMBER: builtins.int
    VERSION_LIST_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    SYS_VER_FIELD_NUMBER: builtins.int
    SCALE_FIELD_NUMBER: builtins.int
    ARCH_FIELD_NUMBER: builtins.int
    LIST_VERSION_FIELD_NUMBER: builtins.int
    pool_name: typing.Text
    """"""

    module_name: typing.Text
    """"""

    @property
    def version_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VersionListReq]:
        """"""
        pass
    env: global___EnvType.ValueType
    """"""

    sys_ver: builtins.int
    """"""

    scale: builtins.int
    """"""

    arch: builtins.int
    """"""

    list_version: builtins.int
    """"""

    def __init__(self,
        *,
        pool_name: typing.Text = ...,
        module_name: typing.Text = ...,
        version_list: typing.Optional[typing.Iterable[global___VersionListReq]] = ...,
        env: global___EnvType.ValueType = ...,
        sys_ver: builtins.int = ...,
        scale: builtins.int = ...,
        arch: builtins.int = ...,
        list_version: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arch",b"arch","env",b"env","list_version",b"list_version","module_name",b"module_name","pool_name",b"pool_name","scale",b"scale","sys_ver",b"sys_ver","version_list",b"version_list"]) -> None: ...
global___ListReq = ListReq

class ModuleReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    TOTAL_MD5_FIELD_NUMBER: builtins.int
    INCREMENT_FIELD_NUMBER: builtins.int
    IS_WIFI_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    FILENAME_FIELD_NUMBER: builtins.int
    FILE_TYPE_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    COMPRESS_FIELD_NUMBER: builtins.int
    PUBLISH_TIME_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    MODULE_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    FILE_ID_FIELD_NUMBER: builtins.int
    ZIP_CHECK_FIELD_NUMBER: builtins.int
    name: typing.Text
    """"""

    version: builtins.int
    """"""

    url: typing.Text
    """"""

    md5: typing.Text
    """"""

    total_md5: typing.Text
    """"""

    increment: global___IncrementType.ValueType
    """"""

    is_wifi: builtins.bool
    """"""

    level: global___LevelType.ValueType
    """"""

    filename: typing.Text
    """"""

    file_type: typing.Text
    """"""

    file_size: builtins.int
    """"""

    compress: global___CompressType.ValueType
    """"""

    publish_time: builtins.int
    """"""

    pool_id: builtins.int
    """上报使用"""

    module_id: builtins.int
    """"""

    version_id: builtins.int
    """"""

    file_id: builtins.int
    """"""

    zip_check: builtins.bool
    """"""

    def __init__(self,
        *,
        name: typing.Text = ...,
        version: builtins.int = ...,
        url: typing.Text = ...,
        md5: typing.Text = ...,
        total_md5: typing.Text = ...,
        increment: global___IncrementType.ValueType = ...,
        is_wifi: builtins.bool = ...,
        level: global___LevelType.ValueType = ...,
        filename: typing.Text = ...,
        file_type: typing.Text = ...,
        file_size: builtins.int = ...,
        compress: global___CompressType.ValueType = ...,
        publish_time: builtins.int = ...,
        pool_id: builtins.int = ...,
        module_id: builtins.int = ...,
        version_id: builtins.int = ...,
        file_id: builtins.int = ...,
        zip_check: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["compress",b"compress","file_id",b"file_id","file_size",b"file_size","file_type",b"file_type","filename",b"filename","increment",b"increment","is_wifi",b"is_wifi","level",b"level","md5",b"md5","module_id",b"module_id","name",b"name","pool_id",b"pool_id","publish_time",b"publish_time","total_md5",b"total_md5","url",b"url","version",b"version","version_id",b"version_id","zip_check",b"zip_check"]) -> None: ...
global___ModuleReply = ModuleReply

class PoolReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    MODULES_FIELD_NUMBER: builtins.int
    name: typing.Text
    """"""

    @property
    def modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModuleReply]:
        """"""
        pass
    def __init__(self,
        *,
        name: typing.Text = ...,
        modules: typing.Optional[typing.Iterable[global___ModuleReply]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["modules",b"modules","name",b"name"]) -> None: ...
global___PoolReply = PoolReply

class VersionListReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POOL_NAME_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    pool_name: typing.Text
    """"""

    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VersionReq]:
        """"""
        pass
    def __init__(self,
        *,
        pool_name: typing.Text = ...,
        versions: typing.Optional[typing.Iterable[global___VersionReq]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_name",b"pool_name","versions",b"versions"]) -> None: ...
global___VersionListReq = VersionListReq

class VersionReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODULE_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    module_name: typing.Text
    """"""

    version: builtins.int
    """"""

    def __init__(self,
        *,
        module_name: typing.Text = ...,
        version: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_name",b"module_name","version",b"version"]) -> None: ...
global___VersionReq = VersionReq



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Locale(google.protobuf.message.Message):
    """区域标识
    gRPC头部:x-bili-locale-bin
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    C_LOCALE_FIELD_NUMBER: builtins.int
    S_LOCALE_FIELD_NUMBER: builtins.int
    SIM_CODE_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    @property
    def c_locale(self) -> global___LocaleIds:
        """App设置的locale"""
        pass
    @property
    def s_locale(self) -> global___LocaleIds:
        """系统默认的locale"""
        pass
    sim_code: typing.Text
    """sim卡的国家码+运营商码"""

    timezone: typing.Text
    """时区"""

    def __init__(self,
        *,
        c_locale: typing.Optional[global___LocaleIds] = ...,
        s_locale: typing.Optional[global___LocaleIds] = ...,
        sim_code: typing.Text = ...,
        timezone: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["c_locale",b"c_locale","s_locale",b"s_locale"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["c_locale",b"c_locale","s_locale",b"s_locale","sim_code",b"sim_code","timezone",b"timezone"]) -> None: ...
global___Locale = Locale

class LocaleIds(google.protobuf.message.Message):
    """Defined by https://developer.apple.com/library/archive/documentation/MacOSX/Conceptual/BPInternational/LanguageandLocaleIDs/LanguageandLocaleIDs.html"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LANGUAGE_FIELD_NUMBER: builtins.int
    SCRIPT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    language: typing.Text
    """A language designator is a code that represents a language."""

    script: typing.Text
    """Writing systems."""

    region: typing.Text
    """A region designator is a code that represents a country or an area."""

    def __init__(self,
        *,
        language: typing.Text = ...,
        script: typing.Text = ...,
        region: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["language",b"language","region",b"region","script",b"script"]) -> None: ...
global___LocaleIds = LocaleIds



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.im.interfaces.v1 import im_pb2 as bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2
from bilireq.grpc.protos.bilibili.im.type import im_pb2 as bilibili_dot_im_dot_type_dot_im__pb2


class ImInterfaceStub(object):
    """私信
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SendMsg = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/SendMsg',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSendMsg.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSendMsg.FromString,
                )
        self.SyncRelation = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/SyncRelation',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqRelationSync.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspRelationSync.FromString,
                )
        self.SyncAck = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/SyncAck',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSyncAck.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSyncAck.FromString,
                )
        self.SyncFetchSessionMsgs = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/SyncFetchSessionMsgs',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSessionMsg.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessionMsg.FromString,
                )
        self.GetSessions = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/GetSessions',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqGetSessions.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessions.FromString,
                )
        self.NewSessions = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/NewSessions',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqNewSessions.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessions.FromString,
                )
        self.AckSessions = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/AckSessions',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqAckSessions.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessions.FromString,
                )
        self.UpdateAck = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/UpdateAck',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqUpdateAck.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.FromString,
                )
        self.SetTop = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/SetTop',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSetTop.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.FromString,
                )
        self.RemoveSession = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/RemoveSession',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqRemoveSession.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.FromString,
                )
        self.SingleUnread = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/SingleUnread',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSingleUnread.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSingleUnread.FromString,
                )
        self.MyGroupUnread = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/MyGroupUnread',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyReq.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspMyGroupUnread.FromString,
                )
        self.UpdateUnflwRead = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/UpdateUnflwRead',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyReq.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.FromString,
                )
        self.GroupAssisMsg = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/GroupAssisMsg',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqGroupAssisMsg.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessionMsg.FromString,
                )
        self.AckAssisMsg = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/AckAssisMsg',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqAckAssisMsg.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.FromString,
                )
        self.SessionDetail = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/SessionDetail',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSessionDetail.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_type_dot_im__pb2.SessionInfo.FromString,
                )
        self.BatchSessDetail = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/BatchSessDetail',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSessionDetails.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessionDetails.FromString,
                )
        self.BatchRmSessions = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/BatchRmSessions',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqBatRmSess.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.FromString,
                )
        self.ShareList = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/ShareList',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqShareList.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspShareList.FromString,
                )
        self.SpecificSingleUnread = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/SpecificSingleUnread',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSpecificSingleUnread.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSpecificSingleUnread.FromString,
                )
        self.GetSpecificSessions = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/GetSpecificSessions',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqGetSpecificSessions.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessions.FromString,
                )
        self.GetLiveInfo = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/GetLiveInfo',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqLiveInfo.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspLiveInfo.FromString,
                )
        self.GetTotalUnread = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/GetTotalUnread',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqTotalUnread.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspTotalUnread.FromString,
                )
        self.ShowClearUnreadUI = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/ShowClearUnreadUI',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqShowClearUnreadUI.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspShowClearUnreadUI.FromString,
                )
        self.CloseClearUnreadUI = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/CloseClearUnreadUI',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqCloseClearUnreadUI.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspCloseClearUnreadUI.FromString,
                )
        self.UpdateTotalUnread = channel.unary_unary(
                '/bilibili.im.interfaces.v1.ImInterface/UpdateTotalUnread',
                request_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqUpdateTotalUnread.SerializeToString,
                response_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspUpdateTotalUnread.FromString,
                )


class ImInterfaceServicer(object):
    """私信
    """

    def SendMsg(self, request, context):
        """发送消息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SyncRelation(self, request, context):
        """同步关系
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SyncAck(self, request, context):
        """确认同步进度
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SyncFetchSessionMsgs(self, request, context):
        """同步版本拉取消息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSessions(self, request, context):
        """拉取会话记录列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NewSessions(self, request, context):
        """拉取新消息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AckSessions(self, request, context):
        """拉取已读消息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAck(self, request, context):
        """更新已读进度
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTop(self, request, context):
        """置顶聊天
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveSession(self, request, context):
        """删除会话记录
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SingleUnread(self, request, context):
        """未读私信数
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MyGroupUnread(self, request, context):
        """我创建的应援团未读数
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUnflwRead(self, request, context):
        """未关注的人批量设置为已读
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupAssisMsg(self, request, context):
        """应援团消息助手
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AckAssisMsg(self, request, context):
        """更新应援团小助手消息已拉取进度
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SessionDetail(self, request, context):
        """拉取会话详情
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchSessDetail(self, request, context):
        """批量拉取会话详情
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchRmSessions(self, request, context):
        """批量删除会话
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShareList(self, request, context):
        """拉取最近私信分享列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SpecificSingleUnread(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSpecificSessions(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLiveInfo(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTotalUnread(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShowClearUnreadUI(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloseClearUnreadUI(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTotalUnread(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ImInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SendMsg': grpc.unary_unary_rpc_method_handler(
                    servicer.SendMsg,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSendMsg.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSendMsg.SerializeToString,
            ),
            'SyncRelation': grpc.unary_unary_rpc_method_handler(
                    servicer.SyncRelation,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqRelationSync.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspRelationSync.SerializeToString,
            ),
            'SyncAck': grpc.unary_unary_rpc_method_handler(
                    servicer.SyncAck,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSyncAck.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSyncAck.SerializeToString,
            ),
            'SyncFetchSessionMsgs': grpc.unary_unary_rpc_method_handler(
                    servicer.SyncFetchSessionMsgs,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSessionMsg.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessionMsg.SerializeToString,
            ),
            'GetSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSessions,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqGetSessions.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessions.SerializeToString,
            ),
            'NewSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.NewSessions,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqNewSessions.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessions.SerializeToString,
            ),
            'AckSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.AckSessions,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqAckSessions.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessions.SerializeToString,
            ),
            'UpdateAck': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAck,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqUpdateAck.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.SerializeToString,
            ),
            'SetTop': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTop,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSetTop.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.SerializeToString,
            ),
            'RemoveSession': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveSession,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqRemoveSession.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.SerializeToString,
            ),
            'SingleUnread': grpc.unary_unary_rpc_method_handler(
                    servicer.SingleUnread,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSingleUnread.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSingleUnread.SerializeToString,
            ),
            'MyGroupUnread': grpc.unary_unary_rpc_method_handler(
                    servicer.MyGroupUnread,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyReq.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspMyGroupUnread.SerializeToString,
            ),
            'UpdateUnflwRead': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUnflwRead,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyReq.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.SerializeToString,
            ),
            'GroupAssisMsg': grpc.unary_unary_rpc_method_handler(
                    servicer.GroupAssisMsg,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqGroupAssisMsg.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessionMsg.SerializeToString,
            ),
            'AckAssisMsg': grpc.unary_unary_rpc_method_handler(
                    servicer.AckAssisMsg,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqAckAssisMsg.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.SerializeToString,
            ),
            'SessionDetail': grpc.unary_unary_rpc_method_handler(
                    servicer.SessionDetail,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSessionDetail.FromString,
                    response_serializer=bilibili_dot_im_dot_type_dot_im__pb2.SessionInfo.SerializeToString,
            ),
            'BatchSessDetail': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchSessDetail,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSessionDetails.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessionDetails.SerializeToString,
            ),
            'BatchRmSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchRmSessions,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqBatRmSess.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.SerializeToString,
            ),
            'ShareList': grpc.unary_unary_rpc_method_handler(
                    servicer.ShareList,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqShareList.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspShareList.SerializeToString,
            ),
            'SpecificSingleUnread': grpc.unary_unary_rpc_method_handler(
                    servicer.SpecificSingleUnread,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSpecificSingleUnread.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSpecificSingleUnread.SerializeToString,
            ),
            'GetSpecificSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSpecificSessions,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqGetSpecificSessions.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessions.SerializeToString,
            ),
            'GetLiveInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLiveInfo,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqLiveInfo.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspLiveInfo.SerializeToString,
            ),
            'GetTotalUnread': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTotalUnread,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqTotalUnread.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspTotalUnread.SerializeToString,
            ),
            'ShowClearUnreadUI': grpc.unary_unary_rpc_method_handler(
                    servicer.ShowClearUnreadUI,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqShowClearUnreadUI.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspShowClearUnreadUI.SerializeToString,
            ),
            'CloseClearUnreadUI': grpc.unary_unary_rpc_method_handler(
                    servicer.CloseClearUnreadUI,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqCloseClearUnreadUI.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspCloseClearUnreadUI.SerializeToString,
            ),
            'UpdateTotalUnread': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTotalUnread,
                    request_deserializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqUpdateTotalUnread.FromString,
                    response_serializer=bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspUpdateTotalUnread.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.im.interfaces.v1.ImInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ImInterface(object):
    """私信
    """

    @staticmethod
    def SendMsg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/SendMsg',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSendMsg.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSendMsg.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SyncRelation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/SyncRelation',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqRelationSync.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspRelationSync.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SyncAck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/SyncAck',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSyncAck.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSyncAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SyncFetchSessionMsgs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/SyncFetchSessionMsgs',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSessionMsg.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessionMsg.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/GetSessions',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqGetSessions.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessions.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NewSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/NewSessions',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqNewSessions.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessions.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AckSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/AckSessions',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqAckSessions.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessions.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/UpdateAck',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqUpdateAck.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetTop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/SetTop',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSetTop.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/RemoveSession',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqRemoveSession.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SingleUnread(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/SingleUnread',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSingleUnread.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSingleUnread.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MyGroupUnread(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/MyGroupUnread',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyReq.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspMyGroupUnread.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUnflwRead(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/UpdateUnflwRead',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyReq.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GroupAssisMsg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/GroupAssisMsg',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqGroupAssisMsg.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessionMsg.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AckAssisMsg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/AckAssisMsg',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqAckAssisMsg.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SessionDetail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/SessionDetail',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSessionDetail.SerializeToString,
            bilibili_dot_im_dot_type_dot_im__pb2.SessionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchSessDetail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/BatchSessDetail',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSessionDetails.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessionDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchRmSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/BatchRmSessions',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqBatRmSess.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.DummyRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShareList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/ShareList',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqShareList.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspShareList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SpecificSingleUnread(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/SpecificSingleUnread',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqSpecificSingleUnread.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSpecificSingleUnread.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSpecificSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/GetSpecificSessions',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqGetSpecificSessions.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspSessions.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLiveInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/GetLiveInfo',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqLiveInfo.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspLiveInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTotalUnread(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/GetTotalUnread',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqTotalUnread.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspTotalUnread.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShowClearUnreadUI(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/ShowClearUnreadUI',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqShowClearUnreadUI.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspShowClearUnreadUI.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CloseClearUnreadUI(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/CloseClearUnreadUI',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqCloseClearUnreadUI.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspCloseClearUnreadUI.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTotalUnread(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.im.interfaces.v1.ImInterface/UpdateTotalUnread',
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.ReqUpdateTotalUnread.SerializeToString,
            bilibili_dot_im_dot_interfaces_dot_v1_dot_im__pb2.RspUpdateTotalUnread.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import bilireq.grpc.protos.bilibili.app.card.v1.card_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Bubble(google.protobuf.message.Message):
    """气泡信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BUBBLE_CONTENT_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    STIME_FIELD_NUMBER: builtins.int
    bubble_content: typing.Text
    """文案"""

    version: builtins.int
    """版本"""

    stime: builtins.int
    """起始时间"""

    def __init__(self,
        *,
        bubble_content: typing.Text = ...,
        version: builtins.int = ...,
        stime: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bubble_content",b"bubble_content","stime",b"stime","version",b"version"]) -> None: ...
global___Bubble = Bubble

class Config(google.protobuf.message.Message):
    """配置信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEM_TITLE_FIELD_NUMBER: builtins.int
    BOTTOM_TEXT_FIELD_NUMBER: builtins.int
    BOTTOM_TEXT_COVER_FIELD_NUMBER: builtins.int
    BOTTOM_TEXT_URL_FIELD_NUMBER: builtins.int
    TOP_ITEMS_FIELD_NUMBER: builtins.int
    HEAD_IMAGE_FIELD_NUMBER: builtins.int
    PAGE_ITEMS_FIELD_NUMBER: builtins.int
    HIT_FIELD_NUMBER: builtins.int
    item_title: typing.Text
    """标题"""

    bottom_text: typing.Text
    """底部文案"""

    bottom_text_cover: typing.Text
    """底部图片url"""

    bottom_text_url: typing.Text
    """底部跳转页url"""

    @property
    def top_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EntranceShow]:
        """顶部按钮信息列表"""
        pass
    head_image: typing.Text
    """头图url"""

    @property
    def page_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EntranceShow]:
        """当前页按钮信息"""
        pass
    hit: builtins.int
    """"""

    def __init__(self,
        *,
        item_title: typing.Text = ...,
        bottom_text: typing.Text = ...,
        bottom_text_cover: typing.Text = ...,
        bottom_text_url: typing.Text = ...,
        top_items: typing.Optional[typing.Iterable[global___EntranceShow]] = ...,
        head_image: typing.Text = ...,
        page_items: typing.Optional[typing.Iterable[global___EntranceShow]] = ...,
        hit: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bottom_text",b"bottom_text","bottom_text_cover",b"bottom_text_cover","bottom_text_url",b"bottom_text_url","head_image",b"head_image","hit",b"hit","item_title",b"item_title","page_items",b"page_items","top_items",b"top_items"]) -> None: ...
global___Config = Config

class EntranceShow(google.protobuf.message.Message):
    """按钮信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    MODULE_ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    BUBBLE_FIELD_NUMBER: builtins.int
    ENTRANCE_ID_FIELD_NUMBER: builtins.int
    TOP_PHOTO_FIELD_NUMBER: builtins.int
    ENTRANCE_TYPE_FIELD_NUMBER: builtins.int
    icon: typing.Text
    """按钮图标url"""

    title: typing.Text
    """按钮名"""

    module_id: typing.Text
    """入口模块id"""

    uri: typing.Text
    """跳转uri"""

    @property
    def bubble(self) -> global___Bubble:
        """气泡信息"""
        pass
    entrance_id: builtins.int
    """入口id"""

    top_photo: typing.Text
    """头图url"""

    entrance_type: builtins.int
    """入口类型"""

    def __init__(self,
        *,
        icon: typing.Text = ...,
        title: typing.Text = ...,
        module_id: typing.Text = ...,
        uri: typing.Text = ...,
        bubble: typing.Optional[global___Bubble] = ...,
        entrance_id: builtins.int = ...,
        top_photo: typing.Text = ...,
        entrance_type: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bubble",b"bubble"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bubble",b"bubble","entrance_id",b"entrance_id","entrance_type",b"entrance_type","icon",b"icon","module_id",b"module_id","title",b"title","top_photo",b"top_photo","uri",b"uri"]) -> None: ...
global___EntranceShow = EntranceShow

class PopularReply(google.protobuf.message.Message):
    """热门列表-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEMS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    VER_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.app.card.v1.card_pb2.Card]:
        """卡片列表"""
        pass
    @property
    def config(self) -> global___Config:
        """配置信息"""
        pass
    ver: typing.Text
    """版本"""

    def __init__(self,
        *,
        items: typing.Optional[typing.Iterable[bilibili.app.card.v1.card_pb2.Card]] = ...,
        config: typing.Optional[global___Config] = ...,
        ver: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config",b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config",b"config","items",b"items","ver",b"ver"]) -> None: ...
global___PopularReply = PopularReply

class PopularResultReq(google.protobuf.message.Message):
    """热门列表-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IDX_FIELD_NUMBER: builtins.int
    LOGIN_EVENT_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    LAST_PARAM_FIELD_NUMBER: builtins.int
    VER_FIELD_NUMBER: builtins.int
    ENTRANCE_ID_FIELD_NUMBER: builtins.int
    LOCATION_IDS_FIELD_NUMBER: builtins.int
    SOURCE_ID_FIELD_NUMBER: builtins.int
    FLUSH_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    idx: builtins.int
    """排位索引id，为上此请求末尾项的idx"""

    login_event: builtins.int
    """登录标识
    1:未登陆用户第一页 2:登陆用户第一页
    """

    qn: builtins.int
    """清晰度(旧版)"""

    fnver: builtins.int
    """视频流版本(旧版)"""

    fnval: builtins.int
    """视频流功能(旧版)"""

    force_host: builtins.int
    """是否强制使用域名(旧版)"""

    fourk: builtins.int
    """是否4K(旧版)"""

    spmid: typing.Text
    """当前页面spm"""

    last_param: typing.Text
    """上此请求末尾项的param"""

    ver: typing.Text
    """上此请求的ver"""

    entrance_id: builtins.int
    """分品类热门的入口ID"""

    location_ids: typing.Text
    """热门定位id集合"""

    source_id: builtins.int
    """0:tag页 1:中间页"""

    flush: builtins.int
    """数据埋点上报
    0:代表手动刷新 1:代表自动刷新
    """

    @property
    def player_args(self) -> bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
        pass
    def __init__(self,
        *,
        idx: builtins.int = ...,
        login_event: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.int = ...,
        spmid: typing.Text = ...,
        last_param: typing.Text = ...,
        ver: typing.Text = ...,
        entrance_id: builtins.int = ...,
        location_ids: typing.Text = ...,
        source_id: builtins.int = ...,
        flush: builtins.int = ...,
        player_args: typing.Optional[bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args",b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entrance_id",b"entrance_id","flush",b"flush","fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","fourk",b"fourk","idx",b"idx","last_param",b"last_param","location_ids",b"location_ids","login_event",b"login_event","player_args",b"player_args","qn",b"qn","source_id",b"source_id","spmid",b"spmid","ver",b"ver"]) -> None: ...
global___PopularResultReq = PopularResultReq



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.broadcast.message.main.native_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetActProgressReq(google.protobuf.message.Message):
    """获取Native页进度数据-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGEID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    pageID: builtins.int
    """Native页id"""

    mid: builtins.int
    """用户mid"""

    def __init__(self,
        *,
        pageID: builtins.int = ...,
        mid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid",b"mid","pageID",b"pageID"]) -> None: ...
global___GetActProgressReq = GetActProgressReq

class GetActProgressReply(google.protobuf.message.Message):
    """获取Native页进度数据-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EVENT_FIELD_NUMBER: builtins.int
    @property
    def event(self) -> bilibili.broadcast.message.main.native_pb2.NativePageEvent:
        """进度数据"""
        pass
    def __init__(self,
        *,
        event: typing.Optional[bilibili.broadcast.message.main.native_pb2.NativePageEvent] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event",b"event"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event",b"event"]) -> None: ...
global___GetActProgressReply = GetActProgressReply



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/interfaces/v1/space.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2
from bilireq.grpc.protos.bilibili.app.archive.v1 import archive_pb2 as bilibili_dot_app_dot_archive_dot_v1_dot_archive__pb2
from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&bilibili/app/interfaces/v1/space.proto\x12\x1a\x62ilibili.app.interfaces.v1\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\x1a%bilibili/app/archive/v1/archive.proto\x1a%bilibili/app/dynamic/v2/dynamic.proto\"A\n\x03\x41rc\x12-\n\x07\x61rchive\x18\x01 \x01(\x0b\x32\x1c.bilibili.app.archive.v1.Arc\x12\x0b\n\x03uri\x18\x02 \x01(\t\"@\n\x07\x44ynamic\x12\x35\n\x07\x64ynamic\x18\x01 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\"N\n\x0eSearchTabReply\x12\r\n\x05\x66ocus\x18\x01 \x01(\x03\x12-\n\x04tabs\x18\x02 \x03(\x0b\x32\x1f.bilibili.app.interfaces.v1.Tab\":\n\x0cSearchTabReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x03 \x01(\x05\"V\n\x12SearchArchiveReply\x12\x31\n\x08\x61rchives\x18\x01 \x03(\x0b\x32\x1f.bilibili.app.interfaces.v1.Arc\x12\r\n\x05total\x18\x02 \x01(\x03\"\x8d\x01\n\x10SearchArchiveReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\n\n\x02pn\x18\x03 \x01(\x03\x12\n\n\x02ps\x18\x04 \x01(\x03\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"Z\n\x12SearchDynamicReply\x12\x35\n\x08\x64ynamics\x18\x01 \x03(\x0b\x32#.bilibili.app.interfaces.v1.Dynamic\x12\r\n\x05total\x18\x02 \x01(\x03\"\x8d\x01\n\x10SearchDynamicReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\n\n\x02pn\x18\x03 \x01(\x03\x12\n\n\x02ps\x18\x04 \x01(\x03\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"!\n\x03Tab\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t*&\n\x04\x46rom\x12\x0e\n\nArchiveTab\x10\x00\x12\x0e\n\nDynamicTab\x10\x01\x32\xc8\x02\n\x05Space\x12\x61\n\tSearchTab\x12(.bilibili.app.interfaces.v1.SearchTabReq\x1a*.bilibili.app.interfaces.v1.SearchTabReply\x12m\n\rSearchArchive\x12,.bilibili.app.interfaces.v1.SearchArchiveReq\x1a..bilibili.app.interfaces.v1.SearchArchiveReply\x12m\n\rSearchDynamic\x12,.bilibili.app.interfaces.v1.SearchDynamicReq\x1a..bilibili.app.interfaces.v1.SearchDynamicReplyb\x06proto3')

_FROM = DESCRIPTOR.enum_types_by_name['From']
From = enum_type_wrapper.EnumTypeWrapper(_FROM)
ArchiveTab = 0
DynamicTab = 1


_ARC = DESCRIPTOR.message_types_by_name['Arc']
_DYNAMIC = DESCRIPTOR.message_types_by_name['Dynamic']
_SEARCHTABREPLY = DESCRIPTOR.message_types_by_name['SearchTabReply']
_SEARCHTABREQ = DESCRIPTOR.message_types_by_name['SearchTabReq']
_SEARCHARCHIVEREPLY = DESCRIPTOR.message_types_by_name['SearchArchiveReply']
_SEARCHARCHIVEREQ = DESCRIPTOR.message_types_by_name['SearchArchiveReq']
_SEARCHDYNAMICREPLY = DESCRIPTOR.message_types_by_name['SearchDynamicReply']
_SEARCHDYNAMICREQ = DESCRIPTOR.message_types_by_name['SearchDynamicReq']
_TAB = DESCRIPTOR.message_types_by_name['Tab']
Arc = _reflection.GeneratedProtocolMessageType('Arc', (_message.Message,), {
  'DESCRIPTOR' : _ARC,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.Arc)
  })
_sym_db.RegisterMessage(Arc)

Dynamic = _reflection.GeneratedProtocolMessageType('Dynamic', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMIC,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.Dynamic)
  })
_sym_db.RegisterMessage(Dynamic)

SearchTabReply = _reflection.GeneratedProtocolMessageType('SearchTabReply', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHTABREPLY,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SearchTabReply)
  })
_sym_db.RegisterMessage(SearchTabReply)

SearchTabReq = _reflection.GeneratedProtocolMessageType('SearchTabReq', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHTABREQ,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SearchTabReq)
  })
_sym_db.RegisterMessage(SearchTabReq)

SearchArchiveReply = _reflection.GeneratedProtocolMessageType('SearchArchiveReply', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHARCHIVEREPLY,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SearchArchiveReply)
  })
_sym_db.RegisterMessage(SearchArchiveReply)

SearchArchiveReq = _reflection.GeneratedProtocolMessageType('SearchArchiveReq', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHARCHIVEREQ,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SearchArchiveReq)
  })
_sym_db.RegisterMessage(SearchArchiveReq)

SearchDynamicReply = _reflection.GeneratedProtocolMessageType('SearchDynamicReply', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHDYNAMICREPLY,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SearchDynamicReply)
  })
_sym_db.RegisterMessage(SearchDynamicReply)

SearchDynamicReq = _reflection.GeneratedProtocolMessageType('SearchDynamicReq', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHDYNAMICREQ,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SearchDynamicReq)
  })
_sym_db.RegisterMessage(SearchDynamicReq)

Tab = _reflection.GeneratedProtocolMessageType('Tab', (_message.Message,), {
  'DESCRIPTOR' : _TAB,
  '__module__' : 'bilibili.app.interfaces.v1.space_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.Tab)
  })
_sym_db.RegisterMessage(Tab)

_SPACE = DESCRIPTOR.services_by_name['Space']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FROM._serialized_start=974
  _FROM._serialized_end=1012
  _ARC._serialized_start=198
  _ARC._serialized_end=263
  _DYNAMIC._serialized_start=265
  _DYNAMIC._serialized_end=329
  _SEARCHTABREPLY._serialized_start=331
  _SEARCHTABREPLY._serialized_end=409
  _SEARCHTABREQ._serialized_start=411
  _SEARCHTABREQ._serialized_end=469
  _SEARCHARCHIVEREPLY._serialized_start=471
  _SEARCHARCHIVEREPLY._serialized_end=557
  _SEARCHARCHIVEREQ._serialized_start=560
  _SEARCHARCHIVEREQ._serialized_end=701
  _SEARCHDYNAMICREPLY._serialized_start=703
  _SEARCHDYNAMICREPLY._serialized_end=793
  _SEARCHDYNAMICREQ._serialized_start=796
  _SEARCHDYNAMICREQ._serialized_end=937
  _TAB._serialized_start=939
  _TAB._serialized_end=972
  _SPACE._serialized_start=1015
  _SPACE._serialized_end=1343
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/im/interfaces/v1/im.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.im.type import im_pb2 as bilibili_dot_im_dot_type_dot_im__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"bilibili/im/interfaces/v1/im.proto\x12\x19\x62ilibili.im.interfaces.v1\x1a\x19\x62ilibili/im/type/im.proto\"\x17\n\x08\x44ummyReq\x12\x0b\n\x03idl\x18\x01 \x01(\r\"\x10\n\x08\x44ummyRspJ\x04\x08\x01\x10\x02\"G\n\x0b\x45motionInfo\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x05\x12\x0f\n\x07gif_url\x18\x04 \x01(\t\"+\n\tMsgDetail\x12\x0f\n\x07msg_key\x18\x01 \x01(\x03\x12\r\n\x05seqno\x18\x02 \x01(\x03\"\x8a\x01\n\x10MsgFeedUnreadRsp\x12G\n\x06unread\x18\x01 \x03(\x0b\x32\x37.bilibili.im.interfaces.v1.MsgFeedUnreadRsp.UnreadEntry\x1a-\n\x0bUnreadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"#\n\x0eReqAckAssisMsg\x12\x11\n\tack_seqno\x18\x01 \x01(\x04\"@\n\x0eReqAckSessions\x12\x10\n\x08\x62\x65gin_ts\x18\x01 \x01(\x04\x12\x0e\n\x06\x65nd_ts\x18\x02 \x01(\r\x12\x0c\n\x04size\x18\x03 \x01(\r\"\x0e\n\x0cReqBatRmSess\"\x17\n\x15ReqCloseClearUnreadUI\"n\n\tReqGetMsg\x12\x11\n\ttalker_id\x18\x01 \x01(\x03\x12\x14\n\x0csession_type\x18\x02 \x01(\x05\x12\x38\n\nmsg_detail\x18\x03 \x03(\x0b\x32$.bilibili.im.interfaces.v1.MsgDetail\"\xc1\x01\n\x0eReqGetSessions\x12\x10\n\x08\x62\x65gin_ts\x18\x01 \x01(\x04\x12\x0e\n\x06\x65nd_ts\x18\x02 \x01(\x04\x12\x0c\n\x04size\x18\x03 \x01(\r\x12\x14\n\x0csession_type\x18\x04 \x01(\r\x12\x15\n\runfollow_fold\x18\x05 \x01(\r\x12\x12\n\ngroup_fold\x18\x06 \x01(\r\x12\x11\n\tsort_rule\x18\x07 \x01(\r\x12\x15\n\rteenager_mode\x18\x08 \x01(\r\x12\x14\n\x0clessons_mode\x18\t \x01(\r\"[\n\x16ReqGetSpecificSessions\x12\x41\n\x0ftalker_sessions\x18\x01 \x03(\x0b\x32(.bilibili.im.interfaces.v1.SimpleSession\"6\n\x10ReqGroupAssisMsg\x12\x14\n\x0c\x63lient_seqno\x18\x01 \x01(\x04\x12\x0c\n\x04size\x18\x02 \x01(\r\"-\n\x0bReqLiveInfo\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x11\n\ttalker_id\x18\x02 \x01(\x03\"]\n\x0eReqNewSessions\x12\x10\n\x08\x62\x65gin_ts\x18\x01 \x01(\x04\x12\x0c\n\x04size\x18\x02 \x01(\r\x12\x15\n\rteenager_mode\x18\x03 \x01(\r\x12\x14\n\x0clessons_mode\x18\x04 \x01(\r\"6\n\x0fReqRelationSync\x12#\n\x1b\x63lient_relation_oplog_seqno\x18\x01 \x01(\x04\";\n\x10ReqRemoveSession\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\"u\n\nReqSendMsg\x12\"\n\x03msg\x18\x01 \x01(\x0b\x32\x15.bilibili.im.type.Msg\x12\x0e\n\x06\x63ookie\x18\x02 \x01(\t\x12\x0f\n\x07\x63ookie2\x18\x03 \x01(\t\x12\x12\n\nerror_code\x18\x04 \x01(\x05\x12\x0e\n\x06\x64\x65v_id\x18\x05 \x01(\t\"H\n\x10ReqSessionDetail\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\x12\x0b\n\x03uid\x18\x03 \x01(\x04\"R\n\x11ReqSessionDetails\x12=\n\x08sess_ids\x18\x01 \x03(\x0b\x32+.bilibili.im.interfaces.v1.ReqSessionDetail\"\x8d\x01\n\rReqSessionMsg\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\x05\x12\x11\n\tend_seqno\x18\x03 \x01(\x04\x12\x13\n\x0b\x62\x65gin_seqno\x18\x04 \x01(\x04\x12\x0c\n\x04size\x18\x05 \x01(\x05\x12\r\n\x05order\x18\x06 \x01(\x05\x12\x0e\n\x06\x64\x65v_id\x18\x07 \x01(\t\"E\n\tReqSetTop\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\x12\x0f\n\x07op_type\x18\x03 \x01(\r\"\x1c\n\x0cReqShareList\x12\x0c\n\x04size\x18\x01 \x01(\x05\"]\n\x14ReqShowClearUnreadUI\x12\x13\n\x0bunread_type\x18\x01 \x01(\x05\x12\x1a\n\x12show_unfollow_list\x18\x02 \x01(\x05\x12\x14\n\x0cshow_dustbin\x18\x04 \x01(\x05\"e\n\x0fReqSingleUnread\x12\x13\n\x0bunread_type\x18\x01 \x01(\x05\x12\x1a\n\x12show_unfollow_list\x18\x02 \x01(\x05\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x14\n\x0cshow_dustbin\x18\x04 \x01(\x05\"\\\n\x17ReqSpecificSingleUnread\x12\x41\n\x0ftalker_sessions\x18\x01 \x03(\x0b\x32(.bilibili.im.interfaces.v1.SimpleSession\"\"\n\nReqSyncAck\x12\x14\n\x0c\x63lient_seqno\x18\x01 \x01(\x04\"\xa3\x01\n\x0eReqTotalUnread\x12\x13\n\x0bunread_type\x18\x01 \x01(\x05\x12\x1a\n\x12show_unfollow_list\x18\x02 \x01(\x05\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x14\n\x0cshow_dustbin\x18\x04 \x01(\x05\x12\x17\n\x0fsingleunread_on\x18\x05 \x01(\x05\x12\x12\n\nmsgfeed_on\x18\x06 \x01(\x05\x12\x10\n\x08sysup_on\x18\x07 \x01(\x05\"J\n\x0cReqUpdateAck\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\x12\x11\n\tack_seqno\x18\x03 \x01(\x04\"D\n\x12ReqUpdateIntercept\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x11\n\ttalker_id\x18\x02 \x01(\x03\x12\x0e\n\x06status\x18\x03 \x01(\x05\"\x16\n\x14ReqUpdateTotalUnread\"\x17\n\x15RspCloseClearUnreadUI\"/\n\tRspGetMsg\x12\"\n\x03msg\x18\x01 \x03(\x0b\x32\x15.bilibili.im.type.Msg\"4\n\x0bRspLiveInfo\x12\x13\n\x0blive_status\x18\x01 \x01(\x03\x12\x10\n\x08jump_url\x18\x02 \x01(\t\"(\n\x10RspMyGroupUnread\x12\x14\n\x0cunread_count\x18\x01 \x01(\r\"\xe6\x01\n\x0fRspRelationSync\x12\x0c\n\x04\x66ull\x18\x01 \x01(\x05\x12\x34\n\rrelation_logs\x18\x02 \x03(\x0b\x32\x1d.bilibili.im.type.RelationLog\x12\x35\n\x0b\x66riend_list\x18\x03 \x03(\x0b\x32 .bilibili.im.type.FriendRelation\x12#\n\x1bserver_relation_oplog_seqno\x18\x04 \x01(\x04\x12\x33\n\ngroup_list\x18\x05 \x03(\x0b\x32\x1f.bilibili.im.type.GroupRelation\"\xa1\x01\n\nRspSendMsg\x12\x0f\n\x07msg_key\x18\x01 \x01(\x04\x12\x37\n\x07\x65_infos\x18\x02 \x03(\x0b\x32&.bilibili.im.interfaces.v1.EmotionInfo\x12\x13\n\x0bmsg_content\x18\x03 \x01(\t\x12\x34\n\rkey_hit_infos\x18\x04 \x01(\x0b\x32\x1d.bilibili.im.type.KeyHitInfos\"F\n\x11RspSessionDetails\x12\x31\n\nsess_infos\x18\x01 \x03(\x0b\x32\x1d.bilibili.im.type.SessionInfo\"\xa9\x01\n\rRspSessionMsg\x12\'\n\x08messages\x18\x01 \x03(\x0b\x32\x15.bilibili.im.type.Msg\x12\x10\n\x08has_more\x18\x02 \x01(\x05\x12\x11\n\tmin_seqno\x18\x03 \x01(\x04\x12\x11\n\tmax_seqno\x18\x04 \x01(\x04\x12\x37\n\x07\x65_infos\x18\x05 \x03(\x0b\x32&.bilibili.im.interfaces.v1.EmotionInfo\"\xa3\x02\n\x0bRspSessions\x12\x33\n\x0csession_list\x18\x01 \x03(\x0b\x32\x1d.bilibili.im.type.SessionInfo\x12\x10\n\x08has_more\x18\x02 \x01(\r\x12\x1d\n\x15\x61nti_disturb_cleaning\x18\x03 \x01(\x08\x12\x1d\n\x15is_address_list_empty\x18\x04 \x01(\x05\x12I\n\nsystem_msg\x18\x05 \x03(\x0b\x32\x35.bilibili.im.interfaces.v1.RspSessions.SystemMsgEntry\x12\x12\n\nshow_level\x18\x06 \x01(\x08\x1a\x30\n\x0eSystemMsgEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"m\n\x0cRspShareList\x12\x41\n\x0csession_list\x18\x01 \x03(\x0b\x32+.bilibili.im.interfaces.v1.ShareSessionInfo\x12\x1a\n\x12IsAddressListEmpty\x18\x02 \x01(\x05\"5\n\x14RspShowClearUnreadUI\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x0c\n\x04text\x18\x02 \x01(\t\"\x8e\x01\n\x0fRspSingleUnread\x12\x17\n\x0funfollow_unread\x18\x01 \x01(\x04\x12\x15\n\rfollow_unread\x18\x02 \x01(\x04\x12\x19\n\x11unfollow_push_msg\x18\x03 \x01(\r\x12\x18\n\x10\x64ustbin_push_msg\x18\x04 \x01(\x05\x12\x16\n\x0e\x64ustbin_unread\x18\x05 \x01(\x03\"\xc9\x01\n\x17RspSpecificSingleUnread\x12`\n\x0ftalkerUnreadCnt\x18\x01 \x03(\x0b\x32G.bilibili.im.interfaces.v1.RspSpecificSingleUnread.TalkerUnreadCntEntry\x12\x14\n\x0c\x61llUnreadCnt\x18\x02 \x01(\x04\x1a\x36\n\x14TalkerUnreadCntEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\"\x0c\n\nRspSyncAck\"\x98\x02\n\x0eRspTotalUnread\x12P\n\x15session_single_unread\x18\x01 \x01(\x0b\x32\x31.bilibili.im.interfaces.v1.SessionSingleUnreadRsp\x12\x44\n\x0fmsg_feed_unread\x18\x02 \x01(\x0b\x32+.bilibili.im.interfaces.v1.MsgFeedUnreadRsp\x12X\n\x1asys_msg_interface_last_msg\x18\x03 \x01(\x0b\x32\x34.bilibili.im.interfaces.v1.SysMsgInterfaceLastMsgRsp\x12\x14\n\x0ctotal_unread\x18\x04 \x01(\x05\"\x16\n\x14RspUpdateTotalUnread\"\x95\x01\n\x16SessionSingleUnreadRsp\x12\x17\n\x0funfollow_unread\x18\x01 \x01(\x03\x12\x15\n\rfollow_unread\x18\x02 \x01(\x03\x12\x19\n\x11unfollow_push_msg\x18\x03 \x01(\x05\x12\x18\n\x10\x64ustbin_push_msg\x18\x04 \x01(\x05\x12\x16\n\x0e\x64ustbin_unread\x18\x05 \x01(\x03\"g\n\x10ShareSessionInfo\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0ctalker_uname\x18\x02 \x01(\t\x12\x13\n\x0btalker_icon\x18\x03 \x01(\t\x12\x15\n\rofficial_type\x18\x04 \x01(\x05\"8\n\rSimpleSession\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\"T\n\x19SysMsgInterfaceLastMsgRsp\x12\x0e\n\x06unread\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\x03*8\n\tENUM_FOLD\x12\x0b\n\x07\x46OLD_NO\x10\x00\x12\x0c\n\x08\x46OLD_YES\x10\x01\x12\x10\n\x0c\x46OLD_UNKNOWN\x10\x02*r\n\x10\x45NUM_UNREAD_TYPE\x12\x13\n\x0fUNREAD_TYPE_ALL\x10\x00\x12\x16\n\x12UNREAD_TYPE_FOLLOW\x10\x01\x12\x18\n\x14UNREAD_TYPE_UNFOLLOW\x10\x02\x12\x17\n\x13UNREAD_TYPE_DUSTBIN\x10\x03*\x8a\x01\n\x0cSESSION_TYPE\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fUN_FOLD_SESSION\x10\x01\x12\x1c\n\x18UN_FOLLOW_SINGLE_SESSION\x10\x02\x12\x14\n\x10MY_GROUP_SESSION\x10\x03\x12\x0f\n\x0b\x41LL_SESSION\x10\x04\x12\x13\n\x0f\x44USTBIN_SESSION\x10\x05\x32\xe8\x14\n\x0bImInterface\x12W\n\x07SendMsg\x12%.bilibili.im.interfaces.v1.ReqSendMsg\x1a%.bilibili.im.interfaces.v1.RspSendMsg\x12\x66\n\x0cSyncRelation\x12*.bilibili.im.interfaces.v1.ReqRelationSync\x1a*.bilibili.im.interfaces.v1.RspRelationSync\x12W\n\x07SyncAck\x12%.bilibili.im.interfaces.v1.ReqSyncAck\x1a%.bilibili.im.interfaces.v1.RspSyncAck\x12j\n\x14SyncFetchSessionMsgs\x12(.bilibili.im.interfaces.v1.ReqSessionMsg\x1a(.bilibili.im.interfaces.v1.RspSessionMsg\x12`\n\x0bGetSessions\x12).bilibili.im.interfaces.v1.ReqGetSessions\x1a&.bilibili.im.interfaces.v1.RspSessions\x12`\n\x0bNewSessions\x12).bilibili.im.interfaces.v1.ReqNewSessions\x1a&.bilibili.im.interfaces.v1.RspSessions\x12`\n\x0b\x41\x63kSessions\x12).bilibili.im.interfaces.v1.ReqAckSessions\x1a&.bilibili.im.interfaces.v1.RspSessions\x12Y\n\tUpdateAck\x12\'.bilibili.im.interfaces.v1.ReqUpdateAck\x1a#.bilibili.im.interfaces.v1.DummyRsp\x12S\n\x06SetTop\x12$.bilibili.im.interfaces.v1.ReqSetTop\x1a#.bilibili.im.interfaces.v1.DummyRsp\x12\x61\n\rRemoveSession\x12+.bilibili.im.interfaces.v1.ReqRemoveSession\x1a#.bilibili.im.interfaces.v1.DummyRsp\x12\x66\n\x0cSingleUnread\x12*.bilibili.im.interfaces.v1.ReqSingleUnread\x1a*.bilibili.im.interfaces.v1.RspSingleUnread\x12\x61\n\rMyGroupUnread\x12#.bilibili.im.interfaces.v1.DummyReq\x1a+.bilibili.im.interfaces.v1.RspMyGroupUnread\x12[\n\x0fUpdateUnflwRead\x12#.bilibili.im.interfaces.v1.DummyReq\x1a#.bilibili.im.interfaces.v1.DummyRsp\x12\x66\n\rGroupAssisMsg\x12+.bilibili.im.interfaces.v1.ReqGroupAssisMsg\x1a(.bilibili.im.interfaces.v1.RspSessionMsg\x12]\n\x0b\x41\x63kAssisMsg\x12).bilibili.im.interfaces.v1.ReqAckAssisMsg\x1a#.bilibili.im.interfaces.v1.DummyRsp\x12[\n\rSessionDetail\x12+.bilibili.im.interfaces.v1.ReqSessionDetail\x1a\x1d.bilibili.im.type.SessionInfo\x12m\n\x0f\x42\x61tchSessDetail\x12,.bilibili.im.interfaces.v1.ReqSessionDetails\x1a,.bilibili.im.interfaces.v1.RspSessionDetails\x12_\n\x0f\x42\x61tchRmSessions\x12\'.bilibili.im.interfaces.v1.ReqBatRmSess\x1a#.bilibili.im.interfaces.v1.DummyRsp\x12]\n\tShareList\x12\'.bilibili.im.interfaces.v1.ReqShareList\x1a\'.bilibili.im.interfaces.v1.RspShareList\x12~\n\x14SpecificSingleUnread\x12\x32.bilibili.im.interfaces.v1.ReqSpecificSingleUnread\x1a\x32.bilibili.im.interfaces.v1.RspSpecificSingleUnread\x12p\n\x13GetSpecificSessions\x12\x31.bilibili.im.interfaces.v1.ReqGetSpecificSessions\x1a&.bilibili.im.interfaces.v1.RspSessions\x12]\n\x0bGetLiveInfo\x12&.bilibili.im.interfaces.v1.ReqLiveInfo\x1a&.bilibili.im.interfaces.v1.RspLiveInfo\x12\x66\n\x0eGetTotalUnread\x12).bilibili.im.interfaces.v1.ReqTotalUnread\x1a).bilibili.im.interfaces.v1.RspTotalUnread\x12u\n\x11ShowClearUnreadUI\x12/.bilibili.im.interfaces.v1.ReqShowClearUnreadUI\x1a/.bilibili.im.interfaces.v1.RspShowClearUnreadUI\x12x\n\x12\x43loseClearUnreadUI\x12\x30.bilibili.im.interfaces.v1.ReqCloseClearUnreadUI\x1a\x30.bilibili.im.interfaces.v1.RspCloseClearUnreadUI\x12u\n\x11UpdateTotalUnread\x12/.bilibili.im.interfaces.v1.ReqUpdateTotalUnread\x1a/.bilibili.im.interfaces.v1.RspUpdateTotalUnreadb\x06proto3')

_ENUM_FOLD = DESCRIPTOR.enum_types_by_name['ENUM_FOLD']
ENUM_FOLD = enum_type_wrapper.EnumTypeWrapper(_ENUM_FOLD)
_ENUM_UNREAD_TYPE = DESCRIPTOR.enum_types_by_name['ENUM_UNREAD_TYPE']
ENUM_UNREAD_TYPE = enum_type_wrapper.EnumTypeWrapper(_ENUM_UNREAD_TYPE)
_SESSION_TYPE = DESCRIPTOR.enum_types_by_name['SESSION_TYPE']
SESSION_TYPE = enum_type_wrapper.EnumTypeWrapper(_SESSION_TYPE)
FOLD_NO = 0
FOLD_YES = 1
FOLD_UNKNOWN = 2
UNREAD_TYPE_ALL = 0
UNREAD_TYPE_FOLLOW = 1
UNREAD_TYPE_UNFOLLOW = 2
UNREAD_TYPE_DUSTBIN = 3
UNKNOWN = 0
UN_FOLD_SESSION = 1
UN_FOLLOW_SINGLE_SESSION = 2
MY_GROUP_SESSION = 3
ALL_SESSION = 4
DUSTBIN_SESSION = 5


_DUMMYREQ = DESCRIPTOR.message_types_by_name['DummyReq']
_DUMMYRSP = DESCRIPTOR.message_types_by_name['DummyRsp']
_EMOTIONINFO = DESCRIPTOR.message_types_by_name['EmotionInfo']
_MSGDETAIL = DESCRIPTOR.message_types_by_name['MsgDetail']
_MSGFEEDUNREADRSP = DESCRIPTOR.message_types_by_name['MsgFeedUnreadRsp']
_MSGFEEDUNREADRSP_UNREADENTRY = _MSGFEEDUNREADRSP.nested_types_by_name['UnreadEntry']
_REQACKASSISMSG = DESCRIPTOR.message_types_by_name['ReqAckAssisMsg']
_REQACKSESSIONS = DESCRIPTOR.message_types_by_name['ReqAckSessions']
_REQBATRMSESS = DESCRIPTOR.message_types_by_name['ReqBatRmSess']
_REQCLOSECLEARUNREADUI = DESCRIPTOR.message_types_by_name['ReqCloseClearUnreadUI']
_REQGETMSG = DESCRIPTOR.message_types_by_name['ReqGetMsg']
_REQGETSESSIONS = DESCRIPTOR.message_types_by_name['ReqGetSessions']
_REQGETSPECIFICSESSIONS = DESCRIPTOR.message_types_by_name['ReqGetSpecificSessions']
_REQGROUPASSISMSG = DESCRIPTOR.message_types_by_name['ReqGroupAssisMsg']
_REQLIVEINFO = DESCRIPTOR.message_types_by_name['ReqLiveInfo']
_REQNEWSESSIONS = DESCRIPTOR.message_types_by_name['ReqNewSessions']
_REQRELATIONSYNC = DESCRIPTOR.message_types_by_name['ReqRelationSync']
_REQREMOVESESSION = DESCRIPTOR.message_types_by_name['ReqRemoveSession']
_REQSENDMSG = DESCRIPTOR.message_types_by_name['ReqSendMsg']
_REQSESSIONDETAIL = DESCRIPTOR.message_types_by_name['ReqSessionDetail']
_REQSESSIONDETAILS = DESCRIPTOR.message_types_by_name['ReqSessionDetails']
_REQSESSIONMSG = DESCRIPTOR.message_types_by_name['ReqSessionMsg']
_REQSETTOP = DESCRIPTOR.message_types_by_name['ReqSetTop']
_REQSHARELIST = DESCRIPTOR.message_types_by_name['ReqShareList']
_REQSHOWCLEARUNREADUI = DESCRIPTOR.message_types_by_name['ReqShowClearUnreadUI']
_REQSINGLEUNREAD = DESCRIPTOR.message_types_by_name['ReqSingleUnread']
_REQSPECIFICSINGLEUNREAD = DESCRIPTOR.message_types_by_name['ReqSpecificSingleUnread']
_REQSYNCACK = DESCRIPTOR.message_types_by_name['ReqSyncAck']
_REQTOTALUNREAD = DESCRIPTOR.message_types_by_name['ReqTotalUnread']
_REQUPDATEACK = DESCRIPTOR.message_types_by_name['ReqUpdateAck']
_REQUPDATEINTERCEPT = DESCRIPTOR.message_types_by_name['ReqUpdateIntercept']
_REQUPDATETOTALUNREAD = DESCRIPTOR.message_types_by_name['ReqUpdateTotalUnread']
_RSPCLOSECLEARUNREADUI = DESCRIPTOR.message_types_by_name['RspCloseClearUnreadUI']
_RSPGETMSG = DESCRIPTOR.message_types_by_name['RspGetMsg']
_RSPLIVEINFO = DESCRIPTOR.message_types_by_name['RspLiveInfo']
_RSPMYGROUPUNREAD = DESCRIPTOR.message_types_by_name['RspMyGroupUnread']
_RSPRELATIONSYNC = DESCRIPTOR.message_types_by_name['RspRelationSync']
_RSPSENDMSG = DESCRIPTOR.message_types_by_name['RspSendMsg']
_RSPSESSIONDETAILS = DESCRIPTOR.message_types_by_name['RspSessionDetails']
_RSPSESSIONMSG = DESCRIPTOR.message_types_by_name['RspSessionMsg']
_RSPSESSIONS = DESCRIPTOR.message_types_by_name['RspSessions']
_RSPSESSIONS_SYSTEMMSGENTRY = _RSPSESSIONS.nested_types_by_name['SystemMsgEntry']
_RSPSHARELIST = DESCRIPTOR.message_types_by_name['RspShareList']
_RSPSHOWCLEARUNREADUI = DESCRIPTOR.message_types_by_name['RspShowClearUnreadUI']
_RSPSINGLEUNREAD = DESCRIPTOR.message_types_by_name['RspSingleUnread']
_RSPSPECIFICSINGLEUNREAD = DESCRIPTOR.message_types_by_name['RspSpecificSingleUnread']
_RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY = _RSPSPECIFICSINGLEUNREAD.nested_types_by_name['TalkerUnreadCntEntry']
_RSPSYNCACK = DESCRIPTOR.message_types_by_name['RspSyncAck']
_RSPTOTALUNREAD = DESCRIPTOR.message_types_by_name['RspTotalUnread']
_RSPUPDATETOTALUNREAD = DESCRIPTOR.message_types_by_name['RspUpdateTotalUnread']
_SESSIONSINGLEUNREADRSP = DESCRIPTOR.message_types_by_name['SessionSingleUnreadRsp']
_SHARESESSIONINFO = DESCRIPTOR.message_types_by_name['ShareSessionInfo']
_SIMPLESESSION = DESCRIPTOR.message_types_by_name['SimpleSession']
_SYSMSGINTERFACELASTMSGRSP = DESCRIPTOR.message_types_by_name['SysMsgInterfaceLastMsgRsp']
DummyReq = _reflection.GeneratedProtocolMessageType('DummyReq', (_message.Message,), {
  'DESCRIPTOR' : _DUMMYREQ,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.DummyReq)
  })
_sym_db.RegisterMessage(DummyReq)

DummyRsp = _reflection.GeneratedProtocolMessageType('DummyRsp', (_message.Message,), {
  'DESCRIPTOR' : _DUMMYRSP,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.DummyRsp)
  })
_sym_db.RegisterMessage(DummyRsp)

EmotionInfo = _reflection.GeneratedProtocolMessageType('EmotionInfo', (_message.Message,), {
  'DESCRIPTOR' : _EMOTIONINFO,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.EmotionInfo)
  })
_sym_db.RegisterMessage(EmotionInfo)

MsgDetail = _reflection.GeneratedProtocolMessageType('MsgDetail', (_message.Message,), {
  'DESCRIPTOR' : _MSGDETAIL,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.MsgDetail)
  })
_sym_db.RegisterMessage(MsgDetail)

MsgFeedUnreadRsp = _reflection.GeneratedProtocolMessageType('MsgFeedUnreadRsp', (_message.Message,), {

  'UnreadEntry' : _reflection.GeneratedProtocolMessageType('UnreadEntry', (_message.Message,), {
    'DESCRIPTOR' : _MSGFEEDUNREADRSP_UNREADENTRY,
    '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.MsgFeedUnreadRsp.UnreadEntry)
    })
  ,
  'DESCRIPTOR' : _MSGFEEDUNREADRSP,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.MsgFeedUnreadRsp)
  })
_sym_db.RegisterMessage(MsgFeedUnreadRsp)
_sym_db.RegisterMessage(MsgFeedUnreadRsp.UnreadEntry)

ReqAckAssisMsg = _reflection.GeneratedProtocolMessageType('ReqAckAssisMsg', (_message.Message,), {
  'DESCRIPTOR' : _REQACKASSISMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqAckAssisMsg)
  })
_sym_db.RegisterMessage(ReqAckAssisMsg)

ReqAckSessions = _reflection.GeneratedProtocolMessageType('ReqAckSessions', (_message.Message,), {
  'DESCRIPTOR' : _REQACKSESSIONS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqAckSessions)
  })
_sym_db.RegisterMessage(ReqAckSessions)

ReqBatRmSess = _reflection.GeneratedProtocolMessageType('ReqBatRmSess', (_message.Message,), {
  'DESCRIPTOR' : _REQBATRMSESS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqBatRmSess)
  })
_sym_db.RegisterMessage(ReqBatRmSess)

ReqCloseClearUnreadUI = _reflection.GeneratedProtocolMessageType('ReqCloseClearUnreadUI', (_message.Message,), {
  'DESCRIPTOR' : _REQCLOSECLEARUNREADUI,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqCloseClearUnreadUI)
  })
_sym_db.RegisterMessage(ReqCloseClearUnreadUI)

ReqGetMsg = _reflection.GeneratedProtocolMessageType('ReqGetMsg', (_message.Message,), {
  'DESCRIPTOR' : _REQGETMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqGetMsg)
  })
_sym_db.RegisterMessage(ReqGetMsg)

ReqGetSessions = _reflection.GeneratedProtocolMessageType('ReqGetSessions', (_message.Message,), {
  'DESCRIPTOR' : _REQGETSESSIONS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqGetSessions)
  })
_sym_db.RegisterMessage(ReqGetSessions)

ReqGetSpecificSessions = _reflection.GeneratedProtocolMessageType('ReqGetSpecificSessions', (_message.Message,), {
  'DESCRIPTOR' : _REQGETSPECIFICSESSIONS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqGetSpecificSessions)
  })
_sym_db.RegisterMessage(ReqGetSpecificSessions)

ReqGroupAssisMsg = _reflection.GeneratedProtocolMessageType('ReqGroupAssisMsg', (_message.Message,), {
  'DESCRIPTOR' : _REQGROUPASSISMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqGroupAssisMsg)
  })
_sym_db.RegisterMessage(ReqGroupAssisMsg)

ReqLiveInfo = _reflection.GeneratedProtocolMessageType('ReqLiveInfo', (_message.Message,), {
  'DESCRIPTOR' : _REQLIVEINFO,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqLiveInfo)
  })
_sym_db.RegisterMessage(ReqLiveInfo)

ReqNewSessions = _reflection.GeneratedProtocolMessageType('ReqNewSessions', (_message.Message,), {
  'DESCRIPTOR' : _REQNEWSESSIONS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqNewSessions)
  })
_sym_db.RegisterMessage(ReqNewSessions)

ReqRelationSync = _reflection.GeneratedProtocolMessageType('ReqRelationSync', (_message.Message,), {
  'DESCRIPTOR' : _REQRELATIONSYNC,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqRelationSync)
  })
_sym_db.RegisterMessage(ReqRelationSync)

ReqRemoveSession = _reflection.GeneratedProtocolMessageType('ReqRemoveSession', (_message.Message,), {
  'DESCRIPTOR' : _REQREMOVESESSION,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqRemoveSession)
  })
_sym_db.RegisterMessage(ReqRemoveSession)

ReqSendMsg = _reflection.GeneratedProtocolMessageType('ReqSendMsg', (_message.Message,), {
  'DESCRIPTOR' : _REQSENDMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSendMsg)
  })
_sym_db.RegisterMessage(ReqSendMsg)

ReqSessionDetail = _reflection.GeneratedProtocolMessageType('ReqSessionDetail', (_message.Message,), {
  'DESCRIPTOR' : _REQSESSIONDETAIL,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSessionDetail)
  })
_sym_db.RegisterMessage(ReqSessionDetail)

ReqSessionDetails = _reflection.GeneratedProtocolMessageType('ReqSessionDetails', (_message.Message,), {
  'DESCRIPTOR' : _REQSESSIONDETAILS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSessionDetails)
  })
_sym_db.RegisterMessage(ReqSessionDetails)

ReqSessionMsg = _reflection.GeneratedProtocolMessageType('ReqSessionMsg', (_message.Message,), {
  'DESCRIPTOR' : _REQSESSIONMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSessionMsg)
  })
_sym_db.RegisterMessage(ReqSessionMsg)

ReqSetTop = _reflection.GeneratedProtocolMessageType('ReqSetTop', (_message.Message,), {
  'DESCRIPTOR' : _REQSETTOP,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSetTop)
  })
_sym_db.RegisterMessage(ReqSetTop)

ReqShareList = _reflection.GeneratedProtocolMessageType('ReqShareList', (_message.Message,), {
  'DESCRIPTOR' : _REQSHARELIST,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqShareList)
  })
_sym_db.RegisterMessage(ReqShareList)

ReqShowClearUnreadUI = _reflection.GeneratedProtocolMessageType('ReqShowClearUnreadUI', (_message.Message,), {
  'DESCRIPTOR' : _REQSHOWCLEARUNREADUI,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqShowClearUnreadUI)
  })
_sym_db.RegisterMessage(ReqShowClearUnreadUI)

ReqSingleUnread = _reflection.GeneratedProtocolMessageType('ReqSingleUnread', (_message.Message,), {
  'DESCRIPTOR' : _REQSINGLEUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSingleUnread)
  })
_sym_db.RegisterMessage(ReqSingleUnread)

ReqSpecificSingleUnread = _reflection.GeneratedProtocolMessageType('ReqSpecificSingleUnread', (_message.Message,), {
  'DESCRIPTOR' : _REQSPECIFICSINGLEUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSpecificSingleUnread)
  })
_sym_db.RegisterMessage(ReqSpecificSingleUnread)

ReqSyncAck = _reflection.GeneratedProtocolMessageType('ReqSyncAck', (_message.Message,), {
  'DESCRIPTOR' : _REQSYNCACK,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqSyncAck)
  })
_sym_db.RegisterMessage(ReqSyncAck)

ReqTotalUnread = _reflection.GeneratedProtocolMessageType('ReqTotalUnread', (_message.Message,), {
  'DESCRIPTOR' : _REQTOTALUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqTotalUnread)
  })
_sym_db.RegisterMessage(ReqTotalUnread)

ReqUpdateAck = _reflection.GeneratedProtocolMessageType('ReqUpdateAck', (_message.Message,), {
  'DESCRIPTOR' : _REQUPDATEACK,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqUpdateAck)
  })
_sym_db.RegisterMessage(ReqUpdateAck)

ReqUpdateIntercept = _reflection.GeneratedProtocolMessageType('ReqUpdateIntercept', (_message.Message,), {
  'DESCRIPTOR' : _REQUPDATEINTERCEPT,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqUpdateIntercept)
  })
_sym_db.RegisterMessage(ReqUpdateIntercept)

ReqUpdateTotalUnread = _reflection.GeneratedProtocolMessageType('ReqUpdateTotalUnread', (_message.Message,), {
  'DESCRIPTOR' : _REQUPDATETOTALUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ReqUpdateTotalUnread)
  })
_sym_db.RegisterMessage(ReqUpdateTotalUnread)

RspCloseClearUnreadUI = _reflection.GeneratedProtocolMessageType('RspCloseClearUnreadUI', (_message.Message,), {
  'DESCRIPTOR' : _RSPCLOSECLEARUNREADUI,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspCloseClearUnreadUI)
  })
_sym_db.RegisterMessage(RspCloseClearUnreadUI)

RspGetMsg = _reflection.GeneratedProtocolMessageType('RspGetMsg', (_message.Message,), {
  'DESCRIPTOR' : _RSPGETMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspGetMsg)
  })
_sym_db.RegisterMessage(RspGetMsg)

RspLiveInfo = _reflection.GeneratedProtocolMessageType('RspLiveInfo', (_message.Message,), {
  'DESCRIPTOR' : _RSPLIVEINFO,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspLiveInfo)
  })
_sym_db.RegisterMessage(RspLiveInfo)

RspMyGroupUnread = _reflection.GeneratedProtocolMessageType('RspMyGroupUnread', (_message.Message,), {
  'DESCRIPTOR' : _RSPMYGROUPUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspMyGroupUnread)
  })
_sym_db.RegisterMessage(RspMyGroupUnread)

RspRelationSync = _reflection.GeneratedProtocolMessageType('RspRelationSync', (_message.Message,), {
  'DESCRIPTOR' : _RSPRELATIONSYNC,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspRelationSync)
  })
_sym_db.RegisterMessage(RspRelationSync)

RspSendMsg = _reflection.GeneratedProtocolMessageType('RspSendMsg', (_message.Message,), {
  'DESCRIPTOR' : _RSPSENDMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSendMsg)
  })
_sym_db.RegisterMessage(RspSendMsg)

RspSessionDetails = _reflection.GeneratedProtocolMessageType('RspSessionDetails', (_message.Message,), {
  'DESCRIPTOR' : _RSPSESSIONDETAILS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSessionDetails)
  })
_sym_db.RegisterMessage(RspSessionDetails)

RspSessionMsg = _reflection.GeneratedProtocolMessageType('RspSessionMsg', (_message.Message,), {
  'DESCRIPTOR' : _RSPSESSIONMSG,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSessionMsg)
  })
_sym_db.RegisterMessage(RspSessionMsg)

RspSessions = _reflection.GeneratedProtocolMessageType('RspSessions', (_message.Message,), {

  'SystemMsgEntry' : _reflection.GeneratedProtocolMessageType('SystemMsgEntry', (_message.Message,), {
    'DESCRIPTOR' : _RSPSESSIONS_SYSTEMMSGENTRY,
    '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSessions.SystemMsgEntry)
    })
  ,
  'DESCRIPTOR' : _RSPSESSIONS,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSessions)
  })
_sym_db.RegisterMessage(RspSessions)
_sym_db.RegisterMessage(RspSessions.SystemMsgEntry)

RspShareList = _reflection.GeneratedProtocolMessageType('RspShareList', (_message.Message,), {
  'DESCRIPTOR' : _RSPSHARELIST,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspShareList)
  })
_sym_db.RegisterMessage(RspShareList)

RspShowClearUnreadUI = _reflection.GeneratedProtocolMessageType('RspShowClearUnreadUI', (_message.Message,), {
  'DESCRIPTOR' : _RSPSHOWCLEARUNREADUI,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspShowClearUnreadUI)
  })
_sym_db.RegisterMessage(RspShowClearUnreadUI)

RspSingleUnread = _reflection.GeneratedProtocolMessageType('RspSingleUnread', (_message.Message,), {
  'DESCRIPTOR' : _RSPSINGLEUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSingleUnread)
  })
_sym_db.RegisterMessage(RspSingleUnread)

RspSpecificSingleUnread = _reflection.GeneratedProtocolMessageType('RspSpecificSingleUnread', (_message.Message,), {

  'TalkerUnreadCntEntry' : _reflection.GeneratedProtocolMessageType('TalkerUnreadCntEntry', (_message.Message,), {
    'DESCRIPTOR' : _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY,
    '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSpecificSingleUnread.TalkerUnreadCntEntry)
    })
  ,
  'DESCRIPTOR' : _RSPSPECIFICSINGLEUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSpecificSingleUnread)
  })
_sym_db.RegisterMessage(RspSpecificSingleUnread)
_sym_db.RegisterMessage(RspSpecificSingleUnread.TalkerUnreadCntEntry)

RspSyncAck = _reflection.GeneratedProtocolMessageType('RspSyncAck', (_message.Message,), {
  'DESCRIPTOR' : _RSPSYNCACK,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspSyncAck)
  })
_sym_db.RegisterMessage(RspSyncAck)

RspTotalUnread = _reflection.GeneratedProtocolMessageType('RspTotalUnread', (_message.Message,), {
  'DESCRIPTOR' : _RSPTOTALUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspTotalUnread)
  })
_sym_db.RegisterMessage(RspTotalUnread)

RspUpdateTotalUnread = _reflection.GeneratedProtocolMessageType('RspUpdateTotalUnread', (_message.Message,), {
  'DESCRIPTOR' : _RSPUPDATETOTALUNREAD,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.RspUpdateTotalUnread)
  })
_sym_db.RegisterMessage(RspUpdateTotalUnread)

SessionSingleUnreadRsp = _reflection.GeneratedProtocolMessageType('SessionSingleUnreadRsp', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONSINGLEUNREADRSP,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.SessionSingleUnreadRsp)
  })
_sym_db.RegisterMessage(SessionSingleUnreadRsp)

ShareSessionInfo = _reflection.GeneratedProtocolMessageType('ShareSessionInfo', (_message.Message,), {
  'DESCRIPTOR' : _SHARESESSIONINFO,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.ShareSessionInfo)
  })
_sym_db.RegisterMessage(ShareSessionInfo)

SimpleSession = _reflection.GeneratedProtocolMessageType('SimpleSession', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLESESSION,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.SimpleSession)
  })
_sym_db.RegisterMessage(SimpleSession)

SysMsgInterfaceLastMsgRsp = _reflection.GeneratedProtocolMessageType('SysMsgInterfaceLastMsgRsp', (_message.Message,), {
  'DESCRIPTOR' : _SYSMSGINTERFACELASTMSGRSP,
  '__module__' : 'bilibili.im.interfaces.v1.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.interfaces.v1.SysMsgInterfaceLastMsgRsp)
  })
_sym_db.RegisterMessage(SysMsgInterfaceLastMsgRsp)

_IMINTERFACE = DESCRIPTOR.services_by_name['ImInterface']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MSGFEEDUNREADRSP_UNREADENTRY._options = None
  _MSGFEEDUNREADRSP_UNREADENTRY._serialized_options = b'8\001'
  _RSPSESSIONS_SYSTEMMSGENTRY._options = None
  _RSPSESSIONS_SYSTEMMSGENTRY._serialized_options = b'8\001'
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._options = None
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._serialized_options = b'8\001'
  _ENUM_FOLD._serialized_start=4782
  _ENUM_FOLD._serialized_end=4838
  _ENUM_UNREAD_TYPE._serialized_start=4840
  _ENUM_UNREAD_TYPE._serialized_end=4954
  _SESSION_TYPE._serialized_start=4957
  _SESSION_TYPE._serialized_end=5095
  _DUMMYREQ._serialized_start=92
  _DUMMYREQ._serialized_end=115
  _DUMMYRSP._serialized_start=117
  _DUMMYRSP._serialized_end=133
  _EMOTIONINFO._serialized_start=135
  _EMOTIONINFO._serialized_end=206
  _MSGDETAIL._serialized_start=208
  _MSGDETAIL._serialized_end=251
  _MSGFEEDUNREADRSP._serialized_start=254
  _MSGFEEDUNREADRSP._serialized_end=392
  _MSGFEEDUNREADRSP_UNREADENTRY._serialized_start=347
  _MSGFEEDUNREADRSP_UNREADENTRY._serialized_end=392
  _REQACKASSISMSG._serialized_start=394
  _REQACKASSISMSG._serialized_end=429
  _REQACKSESSIONS._serialized_start=431
  _REQACKSESSIONS._serialized_end=495
  _REQBATRMSESS._serialized_start=497
  _REQBATRMSESS._serialized_end=511
  _REQCLOSECLEARUNREADUI._serialized_start=513
  _REQCLOSECLEARUNREADUI._serialized_end=536
  _REQGETMSG._serialized_start=538
  _REQGETMSG._serialized_end=648
  _REQGETSESSIONS._serialized_start=651
  _REQGETSESSIONS._serialized_end=844
  _REQGETSPECIFICSESSIONS._serialized_start=846
  _REQGETSPECIFICSESSIONS._serialized_end=937
  _REQGROUPASSISMSG._serialized_start=939
  _REQGROUPASSISMSG._serialized_end=993
  _REQLIVEINFO._serialized_start=995
  _REQLIVEINFO._serialized_end=1040
  _REQNEWSESSIONS._serialized_start=1042
  _REQNEWSESSIONS._serialized_end=1135
  _REQRELATIONSYNC._serialized_start=1137
  _REQRELATIONSYNC._serialized_end=1191
  _REQREMOVESESSION._serialized_start=1193
  _REQREMOVESESSION._serialized_end=1252
  _REQSENDMSG._serialized_start=1254
  _REQSENDMSG._serialized_end=1371
  _REQSESSIONDETAIL._serialized_start=1373
  _REQSESSIONDETAIL._serialized_end=1445
  _REQSESSIONDETAILS._serialized_start=1447
  _REQSESSIONDETAILS._serialized_end=1529
  _REQSESSIONMSG._serialized_start=1532
  _REQSESSIONMSG._serialized_end=1673
  _REQSETTOP._serialized_start=1675
  _REQSETTOP._serialized_end=1744
  _REQSHARELIST._serialized_start=1746
  _REQSHARELIST._serialized_end=1774
  _REQSHOWCLEARUNREADUI._serialized_start=1776
  _REQSHOWCLEARUNREADUI._serialized_end=1869
  _REQSINGLEUNREAD._serialized_start=1871
  _REQSINGLEUNREAD._serialized_end=1972
  _REQSPECIFICSINGLEUNREAD._serialized_start=1974
  _REQSPECIFICSINGLEUNREAD._serialized_end=2066
  _REQSYNCACK._serialized_start=2068
  _REQSYNCACK._serialized_end=2102
  _REQTOTALUNREAD._serialized_start=2105
  _REQTOTALUNREAD._serialized_end=2268
  _REQUPDATEACK._serialized_start=2270
  _REQUPDATEACK._serialized_end=2344
  _REQUPDATEINTERCEPT._serialized_start=2346
  _REQUPDATEINTERCEPT._serialized_end=2414
  _REQUPDATETOTALUNREAD._serialized_start=2416
  _REQUPDATETOTALUNREAD._serialized_end=2438
  _RSPCLOSECLEARUNREADUI._serialized_start=2440
  _RSPCLOSECLEARUNREADUI._serialized_end=2463
  _RSPGETMSG._serialized_start=2465
  _RSPGETMSG._serialized_end=2512
  _RSPLIVEINFO._serialized_start=2514
  _RSPLIVEINFO._serialized_end=2566
  _RSPMYGROUPUNREAD._serialized_start=2568
  _RSPMYGROUPUNREAD._serialized_end=2608
  _RSPRELATIONSYNC._serialized_start=2611
  _RSPRELATIONSYNC._serialized_end=2841
  _RSPSENDMSG._serialized_start=2844
  _RSPSENDMSG._serialized_end=3005
  _RSPSESSIONDETAILS._serialized_start=3007
  _RSPSESSIONDETAILS._serialized_end=3077
  _RSPSESSIONMSG._serialized_start=3080
  _RSPSESSIONMSG._serialized_end=3249
  _RSPSESSIONS._serialized_start=3252
  _RSPSESSIONS._serialized_end=3543
  _RSPSESSIONS_SYSTEMMSGENTRY._serialized_start=3495
  _RSPSESSIONS_SYSTEMMSGENTRY._serialized_end=3543
  _RSPSHARELIST._serialized_start=3545
  _RSPSHARELIST._serialized_end=3654
  _RSPSHOWCLEARUNREADUI._serialized_start=3656
  _RSPSHOWCLEARUNREADUI._serialized_end=3709
  _RSPSINGLEUNREAD._serialized_start=3712
  _RSPSINGLEUNREAD._serialized_end=3854
  _RSPSPECIFICSINGLEUNREAD._serialized_start=3857
  _RSPSPECIFICSINGLEUNREAD._serialized_end=4058
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._serialized_start=4004
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._serialized_end=4058
  _RSPSYNCACK._serialized_start=4060
  _RSPSYNCACK._serialized_end=4072
  _RSPTOTALUNREAD._serialized_start=4075
  _RSPTOTALUNREAD._serialized_end=4355
  _RSPUPDATETOTALUNREAD._serialized_start=4357
  _RSPUPDATETOTALUNREAD._serialized_end=4379
  _SESSIONSINGLEUNREADRSP._serialized_start=4382
  _SESSIONSINGLEUNREADRSP._serialized_end=4531
  _SHARESESSIONINFO._serialized_start=4533
  _SHARESESSIONINFO._serialized_end=4636
  _SIMPLESESSION._serialized_start=4638
  _SIMPLESESSION._serialized_end=4694
  _SYSMSGINTERFACELASTMSGRSP._serialized_start=4696
  _SYSMSGINTERFACELASTMSGRSP._serialized_end=4780
  _IMINTERFACE._serialized_start=5098
  _IMINTERFACE._serialized_end=7762
# @@protoc_insertion_point(module_scope)
